package Bundle::Locale::CLDR::Northamerica;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Northamerica

=head1 CONTENTS

Bundle::Locale::CLDR::Caribbean 0.46.0

Bundle::Locale::CLDR::Centralamerica 0.46.0

Bundle::Locale::CLDR::Northernamerica 0.46.0


=cut

1;

